#
# spec file for package byzanz
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2007 wberrier@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define build_applet 0%{suse_version} < 1310

Name:           byzanz
Version:        0.3.0+git20140619
Release:        5.13
Summary:        Tool to record a running X desktop to an animated GIF file
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://gitlab.gnome.org/Archive/byzanz
Source:         https://launchpad.net/ubuntu/+archive/primary/+files/%{name}_%{version}.orig.tar.xz
BuildRequires:  gettext-devel
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  perl(XML::Parser)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(xdamage)
%if %{build_applet}
BuildRequires:  pkgconfig(libpanelapplet-4.0)
%endif
%if %{build_applet}
%glib2_gsettings_schema_requires
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Byzanz is a simple tool to record a running X desktop to an animated GIF file.
It is implemented as a GNOME applet. A command line tool for testing purposes
is also available.


%lang_package

%prep
%setup -q
# Disable strict build failing - that's for the devs..
sed -i 's:BYZANZ_CVS="yes":BYZANZ_CVS="no":g' configure.ac

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure \
        --disable-schemas-install
make %{?_smp_mflags}

%install
export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL=1
%makeinstall
%find_lang %{name} %{?no_lang_C}

%post
%icon_theme_cache_post
%if %{build_applet}
%glib2_gsettings_schema_post
%endif

%postun
%icon_theme_cache_postun
%if %{build_applet}
%glib2_gsettings_schema_postun
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS
%if %{build_applet}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/byzanzapplet.xml
%{_datadir}/glib-2.0/schemas/org.gnome.byzanz.applet.gschema.xml
%{_datadir}/gnome-panel/4.0/applets/org.gnome.ByzanzApplet.panel-applet
%{_libexecdir}/%{name}-applet
%endif
%{_bindir}/byzanz-playback
%{_bindir}/byzanz-record
%{_datadir}/icons/hicolor/*/apps/byzanz-record-area.*
%{_datadir}/icons/hicolor/*/apps/byzanz-record-desktop.*
%{_datadir}/icons/hicolor/*/apps/byzanz-record-window.*
%{_mandir}/man1/byzanz.1*
%{_mandir}/man1/byzanz-playback.1*
%{_mandir}/man1/byzanz-record.1*

%files lang -f %{name}.lang

%changelog
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sun Apr 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed SPEC file: Replaced broken URL with latest upstream
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Apr  7 2015 dimstar@opensuse.org
- Disable strict build failing: this is generally enabled for the
  developers, not for users.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 0.3.0+git20140619
  + No changelog available
- Replace pkgconfig(gstreamer-0.10) and pkgconfig(gstreamer-app-0.10)
  with pkgconfig(gstreamer-1.0) and pkgconfig(gstreamer-plugins-base-1.0)
  requirements
- Replace pkgconfig(x11) with pkgconfig(xdamage)
- BuildRequire perl(XML::Parser) and gettext-devel; new dependencies
- Build unconditionnally against gtk3 and glib2
- Replace %%gconf_schemas_prereq with %%glib2_gsettings_schema_requires
  and remove gconf2-devel dependency; upstream dropped gconf2 dependency
- Remove obsolete patches
  + byzanz-gnome3.patch
  + byzanz-own-datadir.patch
  + byzanz-gnome-3.3.patch
  + byzanz-make-panel-optional.patch
* Wed Aug 21 2013 dimstar@opensuse.org
- Add byzanz-make-panel-optional.patch: make building the panel
  applet optional.
- Introduce build_applet defines (true for openSUSE < 13.1). If
  evaluated to true, this results in:
  + enabled pkgconfig(libpanelapplet-4.0) BuildRequires.
  + conditional addition of panel-applet related files entries.
- Move gnome-autogen.sh call to %%build section.
- Replace gconf2 BuildRequires with gconf2-devel: it's what we
  actually require. When building the panel applet, this was
  indirectly pulled in.
* Fri Jan  6 2012 vuntz@opensuse.org
- Add byzanz-gnome-3.3.patch: fix use of deprecated APIs in recent
  versions of glib and gtk+. We only apply this patch on 12.2 and
  later, since it's only needed there and require a recent version
  of glib.
- Tweak byzanz-gnome3.patch so that we don't set NANO in
  AS_VERSION() to 1: this enables us to avoid using -Werror, and
  this fixes the build on Factory.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Jul  7 2011 vuntz@opensuse.org
- Correctly use "!%%favor_gtk2": it has to be "!(0%%{?favor_gtk2})",
  since %%favor_gtk2 will expand to a complex expression.
- Add byzanz-own-datadir.patch to move the menu definition to a non
  GNOME 2 directory. This fixes the build on Factory since we will
  own this new directory which is byzanz-specific.
* Thu Jun 23 2011 sbrabec@suse.cz
- Do not call configure in %%prep phase.
* Tue May 31 2011 vuntz@opensuse.org
- Use favor_gtk2 to switch between gtk2 and gtk3 builds.
- Add byzanz-gnome3.patch: ports the applet to GNOME 3, to fix
  build in Factory. Only apply if favor_gtk2 is not set, and call
  gnome-autogen.sh in that case, with a gnome-common BuildRequires.
- For gtk3 build, move to pkgconfig()-style and GNOME 3
  BuildRequires:
  + Old ones: gtk2-devel, gnome-panel-devel,
    gstreamer-0_10-plugins-base-devel, xorg-x11-devel.
  + New ones: cairo, gio-2.0, gstreamer-0.10, gstreamer-app-0.10,
    gtk+-3.0, libpanelapplet-4.0, x11.
* Mon Mar 21 2011 dimstar@opensuse.org
- Update to version 0.2.3:
  + Features:
  - WebM support
  - Updated translations
  + Bugfixes:
  - Fix compile on 64bit machines.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Mar 24 2010 vuntz@opensuse.org
- Update to version 0.2.2:
  + Features:
  - Updated translations
  + Bugfixes:
  - Record the cursor properly on 64bit machines
- Changes from version 0.2.1:
  + Features:
  - Allow recording audio with Theora video.
  - Add an internal debugging format
  - Cache recording on disk. Slow encoders will not consume all
    memory anymore.
- Changes from version 0.2.0:
  + Features:
  - Rework the user interface
  - Support saving to Ogg Theora and Flash Screen video formats
  - Update to latest technologies (Cairo instead of GDK, gvfs
    instead of gnome-vfs)
  +Bugfixes:
  - Work on 16bpp and 8bpp displays (anything that's supported by
    Cairo)
  - Properly be translucent on panels
- Remove gnome-vfs2-devel and libgnomeui-devel BuildRequires.
- Add gstreamer-0_10-plugins-base-devel BuildRequires.
* Mon Aug  3 2009 vuntz@novell.com
- Use libexecdir instead of libdir.
* Sun Jun 14 2009 vuntz@novell.com
- Clean up packaging for Contrib.
* Tue Oct  2 2007 wberrier@gmail.com
- New package, based on the auto debian port
